CHANGES
=======

v2.3.0, 2022-07-31
----------------

* Add support for steps. Thanks @firefly-cpp (#100)


v2.2.0, 2022-01-23
----------------

* Minor release and test improvements. Thanks @firefly-cpp (#76, #77)
* Add support for max and avg power. Thanks @firefly-cpp (#78)


v2.1.0, 2021-12-30
----------------

* Calculate time in HR zones. Thanks @khink (#41)
* Don't throw exceptions when certain data is missing. Thanks @terra-alex (#74)
* Minor updates to dependencies. Thanks pyup-bot


v2.0.0, 2020-12-20
------------------

* Add command to extract the percentage of workout spent in each HR zone. Thanks @khink (#29)
* Drops support for Python 2.7


v1.1.0, 2020-01-10
------------------

* Add distance_values, position_values and started_at attributes. Thanks @janpipek (#23)


v1.0.0, 2018-12-15
------------------

* Add support for Notes field


v0.8.0, 2018-04-27
------------------

* Add coverage, flake8
* Support Python 3
* Move code into its own package
* Add some cycling support (#16)
* Run tests on CI using tox-travis


v0.7.2, 2017-03-02
------------------

* Don't fail if lat/lon not present.


v0.7.1, 2016-08-14
------------------

* Fix for tracks with only 1 trackpoint.


v0.7.0, 2016-01-01
------------------

* Added average altitude support. Thanks @firefly-cpp


v0.6.0, 2014-11-18
------------------

* Added heart rate data & pace support. Thanks @stevedoyle


v0.3.0, 2013-01-09
------------------

* Changed methods to properties


v0.1.0, 2013-01-07
------------------

* Initial release.
